| firstRun,RPhosFate-method | R Documentation |
Calls erosionPrerequisites, erosion, emission,
transportPrerequisites and transport in the mentioned order. While
transport is called for the specified substance only, emission is
called for all substances whose top soil concentrations have been provided.
## S4 method for signature 'RPhosFate'
firstRun(x, substance = "PP")
x |
An S4 |
substance |
A character string specifying the substance to calculate. |
An S4 RPhosFate river catchment object and side effects in
the form of raster files.
subsequentRun
# temporary demonstration project copy
cv_dir <- demoProject()
# load temporary demonstration project
x <- RPhosFate(
cv_dir = cv_dir,
ls_ini = TRUE
)
x <- firstRun(x, "SS")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.